@@ -84,6 +84,41 @@ class IOSCfgLine(BaseCfgLine):
     @property
     def is_intf(self):
         # Includes subinterfaces
+        """Returns a boolean (True or False) to answer whether this 
+        :class:`~models_cisco.IOSCfgLine` is an interface; subinterfaces
+        also return True.
+
+        Returns:
+            - bool.
+
+        This example illustrates use of the method.
+
+        .. code-block:: python
+           :emphasize-lines: 17,20
+
+           >>> config = [
+           ...     '!',
+           ...     'interface Serial1/0',
+           ...     ' ip address 1.1.1.1 255.255.255.252',
+           ...     '!',
+           ...     'interface ATM2/0',
+           ...     ' no ip address',
+           ...     '!',
+           ...     'interface ATM2/0.100 point-to-point',
+           ...     ' ip address 1.1.1.5 255.255.255.252',
+           ...     ' pvc 0/100',
+           ...     '  vbr-nrt 704 704',
+           ...     '!',
+           ...     ]
+           >>> parse = CiscoConfParse(config)
+           >>> obj = parse.find_objects('^interface\sSerial')[0]
+           >>> obj.is_intf
+           True
+           >>> obj = parse.find_objects('^interface\sATM')[0]
+           >>> obj.is_intf
+           True
+           >>>
+        """
         intf_regex = r'^interface\s+(\S+.+)'
         if self.re_match(intf_regex):
             return True
@@ -91,6 +126,40 @@ class IOSCfgLine(BaseCfgLine):
 
     @property
     def is_subintf(self):
+        """Returns a boolean (True or False) to answer whether this 
+        :class:`~models_cisco.IOSCfgLine` is a subinterface.
+
+        Returns:
+            - bool.
+
+        This example illustrates use of the method.
+
+        .. code-block:: python
+           :emphasize-lines: 17,20
+
+           >>> config = [
+           ...     '!',
+           ...     'interface Serial1/0',
+           ...     ' ip address 1.1.1.1 255.255.255.252',
+           ...     '!',
+           ...     'interface ATM2/0',
+           ...     ' no ip address',
+           ...     '!',
+           ...     'interface ATM2/0.100 point-to-point',
+           ...     ' ip address 1.1.1.5 255.255.255.252',
+           ...     ' pvc 0/100',
+           ...     '  vbr-nrt 704 704',
+           ...     '!',
+           ...     ]
+           >>> parse = CiscoConfParse(config)
+           >>> obj = parse.find_objects('^interface\sSerial')[0]
+           >>> obj.is_subintf
+           False
+           >>> obj = parse.find_objects('^interface\sATM')[0]
+           >>> obj.is_subintf
+           True
+           >>>
+        """
         intf_regex = r'^interface\s+(\S+?\.\d+)'
         if self.re_match(intf_regex):
             return True
@@ -105,6 +174,35 @@ class IOSCfgLine(BaseCfgLine):
 
     @property
     def is_loopback_intf(self):
+        """Returns a boolean (True or False) to answer whether this 
+        :class:`~models_cisco.IOSCfgLine` is a loopback interface.
+
+        Returns:
+            - bool.
+
+        This example illustrates use of the method.
+
+        .. code-block:: python
+           :emphasize-lines: 11,14
+
+           >>> config = [
+           ...     '!',
+           ...     'interface FastEthernet1/0',
+           ...     ' ip address 1.1.1.1 255.255.255.252',
+           ...     '!',
+           ...     'interface Loopback0',
+           ...     ' ip address 1.1.1.5 255.255.255.255',
+           ...     '!',
+           ...     ]
+           >>> parse = CiscoConfParse(config)
+           >>> obj = parse.find_objects('^interface\sFast')[0]
+           >>> obj.is_loopback_intf
+           False
+           >>> obj = parse.find_objects('^interface\sLoop')[0]
+           >>> obj.is_loopback_intf
+           True
+           >>>
+        """
         intf_regex = r'^interface\s+(\Soopback)'
         if self.re_match(intf_regex):
             return True
@@ -112,6 +210,42 @@ class IOSCfgLine(BaseCfgLine):
 
     @property
     def is_ethernet_intf(self):
+        """Returns a boolean (True or False) to answer whether this 
+        :class:`~models_cisco.IOSCfgLine` is an ethernet interface.
+        Any ethernet interface (10M through 10G) is considered an ethernet
+        interface.
+
+        Returns:
+            - bool.
+
+        This example illustrates use of the method.
+
+        .. code-block:: python
+           :emphasize-lines: 17,20
+
+           >>> config = [
+           ...     '!',
+           ...     'interface FastEthernet1/0',
+           ...     ' ip address 1.1.1.1 255.255.255.252',
+           ...     '!',
+           ...     'interface ATM2/0',
+           ...     ' no ip address',
+           ...     '!',
+           ...     'interface ATM2/0.100 point-to-point',
+           ...     ' ip address 1.1.1.5 255.255.255.252',
+           ...     ' pvc 0/100',
+           ...     '  vbr-nrt 704 704',
+           ...     '!',
+           ...     ]
+           >>> parse = CiscoConfParse(config)
+           >>> obj = parse.find_objects('^interface\sFast')[0]
+           >>> obj.is_ethernet_intf
+           True
+           >>> obj = parse.find_objects('^interface\sATM')[0]
+           >>> obj.is_ethernet_intf
+           False
+           >>>
+        """
         intf_regex = r'^interface\s+(.*?\Sthernet)'
         if self.re_match(intf_regex):
             return True
@@ -140,7 +274,9 @@ class BaseIOSIntfLine(IOSCfgLine):
             if self.ipv4_addr_object==self.default_ipv4_addr_object:
                 addr = "No IPv4"
             else:
-                addr = self.ipv4_addr_object
+                ip = str(self.ipv4_addr_object.ip)
+                prefixlen = str(self.ipv4_addr_object.prefixlen)
+                addr = "{0}/{1}".format(ip, prefixlen)
             return "<%s # %s '%s' info: '%s'>" % (self.classname, 
                 self.linenum, self.name, addr)
         else:
@@ -172,7 +308,42 @@ class BaseIOSIntfLine(IOSCfgLine):
 
     @property
     def name(self):
-        """Return a string, such as 'GigabitEthernet0/1'"""
+        """Return the interface name as a string, such as 'GigabitEthernet0/1'
+
+        Returns:
+            - str.  The interface name as a string, or '' if the object is not an interface.
+
+        This example illustrates use of the method.
+
+        .. code-block:: python
+           :emphasize-lines: 17,20,23
+
+           >>> config = [
+           ...     '!',
+           ...     'interface FastEthernet1/0',
+           ...     ' ip address 1.1.1.1 255.255.255.252',
+           ...     '!',
+           ...     'interface ATM2/0',
+           ...     ' no ip address',
+           ...     '!',
+           ...     'interface ATM2/0.100 point-to-point',
+           ...     ' ip address 1.1.1.5 255.255.255.252',
+           ...     ' pvc 0/100',
+           ...     '  vbr-nrt 704 704',
+           ...     '!',
+           ...     ]
+           >>> parse = CiscoConfParse(config, factory=True)
+           >>> obj = parse.find_objects('^interface\sFast')[0]
+           >>> obj.name
+           'FastEthernet1/0'
+           >>> obj = parse.find_objects('^interface\sATM')[0]
+           >>> obj.name
+           'ATM2/0'
+           >>> obj = parse.find_objects('^interface\sATM')[1]
+           >>> obj.name
+           'ATM2/0.100'
+           >>>
+        """
         if not self.is_intf:
             return ''
         intf_regex = r'^interface\s+(\S+[0-9\/\.\s]+)\s*'
@@ -181,32 +352,133 @@ class BaseIOSIntfLine(IOSCfgLine):
 
     @property
     def port(self):
-        """Return the interface's port number"""
+        """Return the interface's port number
+
+        Returns:
+            - int.  The interface number.
+
+        This example illustrates use of the method.
+
+        .. code-block:: python
+           :emphasize-lines: 17,20
+
+           >>> config = [
+           ...     '!',
+           ...     'interface FastEthernet1/0',
+           ...     ' ip address 1.1.1.1 255.255.255.252',
+           ...     '!',
+           ...     'interface ATM2/0',
+           ...     ' no ip address',
+           ...     '!',
+           ...     'interface ATM2/0.100 point-to-point',
+           ...     ' ip address 1.1.1.5 255.255.255.252',
+           ...     ' pvc 0/100',
+           ...     '  vbr-nrt 704 704',
+           ...     '!',
+           ...     ]
+           >>> parse = CiscoConfParse(config, factory=True)
+           >>> obj = parse.find_objects('^interface\sFast')[0]
+           >>> obj.port
+           0
+           >>> obj = parse.find_objects('^interface\sATM')[0]
+           >>> obj.port
+           0
+           >>>
+        """
         return self.ordinal_list[-1]
 
     @property
     def port_type(self):
-        """Return Loopback, ATM, GigabitEthernet, Virtual-Template, etc..."""
+        """Return Loopback, ATM, GigabitEthernet, Virtual-Template, etc...
+
+        Returns:
+            - str.  The port type.
+
+        This example illustrates use of the method.
+
+        .. code-block:: python
+           :emphasize-lines: 17,20
+
+           >>> config = [
+           ...     '!',
+           ...     'interface FastEthernet1/0',
+           ...     ' ip address 1.1.1.1 255.255.255.252',
+           ...     '!',
+           ...     'interface ATM2/0',
+           ...     ' no ip address',
+           ...     '!',
+           ...     'interface ATM2/0.100 point-to-point',
+           ...     ' ip address 1.1.1.5 255.255.255.252',
+           ...     ' pvc 0/100',
+           ...     '  vbr-nrt 704 704',
+           ...     '!',
+           ...     ]
+           >>> parse = CiscoConfParse(config, factory=True)
+           >>> obj = parse.find_objects('^interface\sFast')[0]
+           >>> obj.port_type
+           'FastEthernet'
+           >>> obj = parse.find_objects('^interface\sATM')[0]
+           >>> obj.port_type
+           'ATM'
+           >>>
+        """
         port_type_regex = r'^interface\s+([A-Za-z\-]+)'
         return self.re_match(port_type_regex, group=1, default='')
 
     @property
     def ordinal_list(self):
-        """Return a list of numbers representing card, slot, port for this interface.  If you call ordinal_list on GigabitEthernet2/25.100, you'll get this python list of integers: [2, 25].  If you call ordinal_list on GigabitEthernet2/0/25.100 you'll get this python list of integers: [2, 0, 25].  This method strips all subinterface information in the returned value.
+        """Return a tuple of numbers representing card, slot, port for this interface.  If you call ordinal_list on GigabitEthernet2/25.100, you'll get this python tuple of integers: (2, 25).  If you call ordinal_list on GigabitEthernet2/0/25.100 you'll get this python list of integers: (2, 0, 25).  This method strips all subinterface information in the returned value.
 
-        ..warning:: ordinal_list should silently fail (returning an empty python list) if the interface doesn't parse correctly"""
+        Returns:
+            - tuple.  A tuple of port numbers as integers.
+
+        .. warning::
+
+           ordinal_list should silently fail (returning an empty python list) if the interface doesn't parse correctly
+
+        This example illustrates use of the method.
+
+        .. code-block:: python
+           :emphasize-lines: 17,20
+
+           >>> config = [
+           ...     '!',
+           ...     'interface FastEthernet1/0',
+           ...     ' ip address 1.1.1.1 255.255.255.252',
+           ...     '!',
+           ...     'interface ATM2/0',
+           ...     ' no ip address',
+           ...     '!',
+           ...     'interface ATM2/0.100 point-to-point',
+           ...     ' ip address 1.1.1.5 255.255.255.252',
+           ...     ' pvc 0/100',
+           ...     '  vbr-nrt 704 704',
+           ...     '!',
+           ...     ]
+           >>> parse = CiscoConfParse(config, factory=True)
+           >>> obj = parse.find_objects('^interface\sFast')[0]
+           >>> obj.ordinal_list
+           (1, 0)
+           >>> obj = parse.find_objects('^interface\sATM')[0]
+           >>> obj.ordinal_list
+           (2, 0)
+           >>>
+        """
         if not self.is_intf:
-            return []
+            return ()
         else:
             intf_regex = r'^interface\s+[A-Za-z\-]+\s*(\d+.*?)(\.\d+)*(\s\S+)*\s*$'
             intf_number = self.re_match(intf_regex, group=1, default='')
             if intf_number:
-                return [int(ii) for ii in intf_number.split('/')]
+                return tuple([int(ii) for ii in intf_number.split('/')])
             else:
-                return []
+                return ()
 
     @property
     def description(self):
+        """Return the current interface description string.
+
+        """
         retval = self.re_match_iter_typed(r'^\s*description\s+(\S.+)$',
             result_type=str, default='')
         return retval
@@ -271,13 +543,11 @@ class BaseIOSIntfLine(IOSCfgLine):
 
     @property
     def ip_network_object(self):
+        # Simplified on 2014-12-02
         try:
-            return IPv4Obj('%s/%s' % (self.ipv4_addr, self.ipv4_netmask), 
-                strict=False).network
-        except AttributeError:
-            return IPv4Obj('%s/%s' % (self.ipv4_addr, self.ipv4_netmask), 
-                strict=False).network_address
-        except:
+            return IPv4Obj('{0}/{1}'.format(self.ipv4_addr, self.ipv4_netmask), 
+                strict=False)
+        except (Exception) as e:
             return self.default_ipv4_addr_object
 
 
@@ -338,6 +608,42 @@ class BaseIOSIntfLine(IOSCfgLine):
     def manual_mtu(self):
         ## Due to the diverse platform defaults, this should be the
         ##    only mtu information I plan to support
+        """Returns a integer value for the manual MTU configured on an
+        :class:`~models_cisco.IOSIntfLine` object.  Interfaces without a
+        manual MTU configuration return 0.
+
+        Returns:
+            - integer.
+
+        This example illustrates use of the method.
+
+        .. code-block:: python
+           :emphasize-lines: 18,21
+
+           >>> config = [
+           ...     '!',
+           ...     'interface FastEthernet1/0',
+           ...     ' ip address 1.1.1.1 255.255.255.252',
+           ...     '!',
+           ...     'interface ATM2/0',
+           ...     ' mtu 4470',
+           ...     ' no ip address',
+           ...     '!',
+           ...     'interface ATM2/0.100 point-to-point',
+           ...     ' ip address 1.1.1.5 255.255.255.252',
+           ...     ' pvc 0/100',
+           ...     '  vbr-nrt 704 704',
+           ...     '!',
+           ...     ]
+           >>> parse = CiscoConfParse(config, factory=True)
+           >>> obj = parse.find_objects('^interface\sFast')[0]
+           >>> obj.manual_mtu
+           0
+           >>> obj = parse.find_objects('^interface\sATM')[0]
+           >>> obj.manual_mtu
+           4470
+           >>>
+        """
         retval = self.re_match_iter_typed(r'^\s*mtu\s+(\d+)$',
             result_type=int, default=0)
         return retval
@@ -413,13 +719,54 @@ class BaseIOSIntfLine(IOSCfgLine):
         return 0
 
     def in_ipv4_subnet(self, ipv4network=IPv4Obj('0.0.0.0/32', strict=False)):
-        """Accept two string arguments for network and netmask, and return a boolean for whether this interface is within the requested subnet.  Return None if there is no address on the interface"""
+        """Accept an argument for the :class:`~ccp_util.IPv4Obj` to be 
+        considered, and return a boolean for whether this interface is within 
+        the requested :class:`~ccp_util.IPv4Obj`.
+
+        Kwargs:
+           - ipv4network (:class:`~ccp_util.IPv4Obj`): An object to compare against IP addresses configured on this :class:`~models_cisco.IOSIntfLine` object.
+
+        Returns:
+            - bool if there is an ip address, or None if there is no ip address.
+
+        This example illustrates use of the method.
+
+        .. code-block:: python
+           :emphasize-lines: 21,23
+
+           >>> from ciscoconfparse.ccp_util import IPv4Obj
+           >>> from ciscoconfparse import CiscoConfParse
+           >>> config = [
+           ...     '!',
+           ...     'interface Serial1/0',
+           ...     ' ip address 1.1.1.1 255.255.255.252',
+           ...     '!',
+           ...     'interface ATM2/0',
+           ...     ' no ip address',
+           ...     '!',
+           ...     'interface ATM2/0.100 point-to-point',
+           ...     ' ip address 1.1.1.5 255.255.255.252',
+           ...     ' pvc 0/100',
+           ...     '  vbr-nrt 704 704',
+           ...     '!',
+           ...     ]
+           >>> parse = CiscoConfParse(config, factory=True)
+           >>> obj = parse.find_objects('^interface\sSerial')[0]
+           >>> obj
+           <IOSIntfLine # 1 'Serial1/0' info: '1.1.1.1/30'>
+           >>> obj.in_ipv4_subnet(IPv4Obj('1.1.1.0/24', strict=False))
+           True
+           >>> obj.in_ipv4_subnet(IPv4Obj('2.1.1.0/24', strict=False))
+           False
+           >>>
+        """
         if not (str(self.ipv4_addr_object.ip)=="127.0.0.1"):
             try:
-                # Return a boolean for whether the interface is in that network and mask
-                return self.ipv4_addr_object in ipv4network
-            except:
-                raise ValueError("FATAL: %s.in_ipv4_subnet(ipv4network={0}) is an invalid arg".format(ipv4network))
+                # Return a boolean for whether the interface is in that 
+                #    network and mask
+                return self.ipv4_network_object in ipv4network
+            except (Exception) as e:
+                raise ValueError("FATAL: %s.in_ipv4_subnet(ipv4network={0}) is an invalid arg: {1}".format(ipv4network, e))
         else:
             return None
 
@@ -466,6 +813,32 @@ class BaseIOSIntfLine(IOSCfgLine):
         ## NOTE: I have no intention of checking self.is_shutdown here
         ##     People should be able to check the sanity of interfaces
         ##     before they put them into production
+        """Return a boolean for whether no ip proxy-arp is configured on the 
+        interface.
+
+        Returns:
+            - bool.
+
+        This example illustrates use of the method.
+
+        .. code-block:: python
+           :emphasize-lines: 12
+
+           >>> from ciscoconfparse.ccp_util import IPv4Obj
+           >>> from ciscoconfparse import CiscoConfParse
+           >>> config = [
+           ...     '!',
+           ...     'interface FastEthernet1/0',
+           ...     ' ip address 1.1.1.1 255.255.255.252',
+           ...     ' no ip proxy-arp',
+           ...     '!',
+           ...     ]
+           >>> parse = CiscoConfParse(config, factory=True)
+           >>> obj = parse.find_objects('^interface\sFast')[0]
+           >>> obj.has_no_ip_proxyarp
+           True
+           >>>
+        """
 
         ## Interface must have an IP addr to respond
         if (self.ipv4_addr==''):
@@ -473,6 +846,7 @@ class BaseIOSIntfLine(IOSCfgLine):
 
         ## By default, Cisco IOS answers proxy-arp
         ## By default, Nexus disables proxy-arp
+        ## By default, IOS-XR disables proxy-arp
         retval = self.re_match_iter_typed(r'^\s*no\sip\s(proxy-arp)\s*$',
             result_type=bool, default=False)
         return retval
@@ -813,7 +1187,12 @@ class IOSIntfLine(BaseIOSIntfLine):
 
     def __init__(self, *args, **kwargs):
         """Accept an IOS line number and initialize family relationship
-        attributes"""
+        attributes
+
+        .. warning::
+
+          All :class:`~models_cisco.IOSIntfLine` methods are still considered beta-quality, until this notice is removed.  The behavior of APIs on this object could change at any time.
+        """
         super(IOSIntfLine, self).__init__(*args, **kwargs)
 
     @classmethod
